@@ -142,11 +142,9 @@ def plot_time_series(df, date_col=None, categorical_col=None, num_cols=None, agg
             fig.show()
     else:
         new_df = df.groupby([categorical_col, date_col]).agg(aggregation).reset_index(date_col)
-        print(new_df)
         for num in num_cols:
             fig = go.Figure()
             for cat in new_df.index.unique():
-                print(new_df.loc[cat][date_col], 'aaaaaaa')
                 fig.add_trace(go.Scatter(x=pd.Series(new_df.loc[cat][date_col]), y=pd.Series(new_df.loc[cat][num]), name=cat))
                 fig.update_layout(title_text=num + " overtime")
             fig.show()
@@ -183,7 +181,10 @@ def plot_two_time_series(df, date_col, num_col_1, num_col_2, two_axis=False, agg
         df[date_col] = pd.to_datetime(df[date_col])
     df.sort_values(by=date_col, inplace = True)
     
-    aggregation = {'a': 'sum', 'b': 'sum'}
+    aggregation = {}
+    aggregation[num_col_1] = 'sum'
+    aggregation[num_col_2] = 'sum'
+    
     if agg is not None:
         if type(agg) is not dict:
             raise ValueError('agg must be a dict !')
@@ -220,7 +221,7 @@ def plot_two_time_series(df, date_col, num_col_1, num_col_2, two_axis=False, agg
 
         # Add figure title
         fig.update_layout(
-            title_text=num_col_1+" vs "+num_col_2
+            title_text=num_col_1+" vs. "+num_col_2
         )
 
         # Set x-axis title
@@ -334,4 +335,156 @@ def plot_boxplots(df, num_cols, categorical_col=None):
             fig.update_layout(title="Box Plots by "+categorical_col+" ("+num_col+")")
             fig.show()
 
+def plot_AVM(dates, y_true, y_pred, dates_test=None, y_true_test=None, y_pred_test=None):
+    """
+    Plot Actual vs. Predicted values along with Mean Absolute Percentage Error (MAPE) bars.
+
+    Parameters:
+    ----------
+    dates : list-like
+        List of dates or date-like objects corresponding to the data points.
+    y_true : list-like
+        List of actual target values.
+    y_pred : list-like
+        List of predicted target values.
+    dates_test : list-like, optional
+        List of dates or date-like objects corresponding to the test data points.
+    y_true_test : list-like, optional
+        List of actual target values for the test data points.
+    y_pred_test : list-like, optional
+        List of predicted target values for the test data points.
+
+    Returns:
+    -------
+    None
+
+    The function generates a plot that displays the actual and predicted values along with
+    bars representing the Mean Absolute Percentage Error (MAPE) between actual and predicted values.
+
+    If test data is provided, additional traces and bars are plotted for the test data.
+    """
+
+    df = pd.DataFrame({'date': dates,
+                       'y_true': y_true,
+                       'y_pred': y_pred})
     
+    df['mape'] = abs(df['y_true'] - df['y_pred']) / df['y_true']
+    df['mape'] = df['mape'].apply(lambda x: min(1,x))
+
+    if np.issubdtype(df['date'].dtype, np.object_):
+        df['date'] = pd.to_datetime(df['date'])
+
+    df.sort_values(by='date', inplace=True)
+
+    fig = make_subplots(specs=[[{"secondary_y": True}]])
+    
+    fig.add_trace(go.Scatter(x=df['date'], y=df['y_true'], name="y_true"))
+    
+    fig.add_trace(go.Scatter(x=df['date'], y=df['y_pred'], name='y_pred',
+                         line = dict(dash='dash')))
+    
+    fig.add_trace(go.Bar(x=df['date'], y=df['mape'], name="mape", opacity=0.3), secondary_y=True)
+    
+    if dates_test is not None and y_true_test is not None and y_pred_test is not None:
+        df_test = pd.DataFrame({'dates_test': dates_test,
+                                'y_true_test': y_true_test,
+                                'y_pred_test': y_pred_test})
+        
+        df_test['mape_test'] = abs(df_test['y_true_test'] - df_test['y_pred_test']) / df_test['y_true_test']
+        df_test['mape_test'] = df_test['mape_test'].apply(lambda x: min(1,x))
+
+        if np.issubdtype(df_test['dates_test'].dtype, np.object_):
+            df_test['dates_test'] = pd.to_datetime(df_test['dates_test'])
+
+        df_test.sort_values(by='dates_test', inplace=True)
+    
+        fig.add_trace(go.Scatter(x=df_test['dates_test'], y=df_test['y_true_test'], name="y_true_train"))
+    
+        fig.add_trace(go.Scatter(x=df_test['dates_test'], y=df_test['y_pred_test'], name='y_pred_train',
+                            line = dict(dash='dash')))
+    
+        fig.add_trace(go.Bar(x=df_test['dates_test'], y=df_test['mape_test'], name="mape_train", opacity=0.3), secondary_y=True)
+
+    fig.update_layout(title="Actual vs. Predicted")
+    fig.update_yaxes(title_text="Mape", secondary_y=True)
+
+    fig.show()
+
+def plot_stacked_vs_lines(df,date_col, stacked_cols, lines_cols, two_axis=False, agg=None):
+    """
+    Create a plot with filled area plots and line plots to compare data trends over time.
+
+    Parameters:
+    ----------
+    df : pandas.DataFrame
+        The input DataFrame containing the data to be plotted.
+    date_col : str
+        The column name in `df` representing the date or time period.
+    stacked_cols : list-like
+        List of column names to be represented as filled area plots in the plot.
+    lines_cols : str or list-like
+        Column name or list of column names to be represented as line plots in the plot.
+    two_axis : bool, optional
+        If True, use a secondary y-axis for line plots (default is False).
+    agg : dict, optional
+        A dictionary specifying custom aggregation functions for columns.
+        Keys should match the column names, and values should be aggregation functions.
+        Example: {'column_name': 'mean', 'other_column': 'sum'}
+
+    Returns:
+    -------
+    None
+
+    The function generates a plot that displays the trends of specified columns over time,
+    with filled area plots for some columns and line plots for others. It is useful for
+    visualizing and comparing multiple data series with different scales and formats.
+
+    If `two_axis` is set to True, the line plots are displayed on a secondary y-axis.
+
+    If `agg` is provided, custom aggregation functions can be applied to the specified columns
+    during data preprocessing before plotting.
+    """
+
+    if np.issubdtype(df[date_col].dtype, np.object_):
+        df[date_col] = pd.to_datetime(df[date_col])
+
+    df.sort_values(by=date_col, inplace=True)
+    
+    if two_axis:
+        fig = make_subplots(specs=[[{"secondary_y": True}]])
+    else:
+        fig = go.Figure()
+
+    if type(lines_cols) is str:
+        lines_cols = [lines_cols]
+
+    aggregation = {}
+    for num in stacked_cols:
+        aggregation[num] = 'sum'
+    for num in lines_cols:
+        aggregation[num] = 'sum'
+    
+    if agg is not None:
+        if type(agg) is not dict:
+            raise ValueError('agg must be a dict !')
+        elif set(agg.keys()).issubset(set(aggregation.keys())) == False:
+            raise ValueError('Wrong keys for the agg variable')
+        
+        for num in stacked_cols:
+            if num in agg.keys():
+                aggregation[num] = agg[num]
+        for num in lines_cols:
+            if num in agg.keys():
+                aggregation[num] = agg[num]
+    
+    new_df = df.groupby(date_col).agg(aggregation).reset_index()
+    for col in stacked_cols:
+        fig.add_trace(go.Scatter(name=col, x=new_df[date_col], y=new_df[col], mode='lines', stackgroup='one'))
+
+    for col in lines_cols:
+        if two_axis:
+            fig.add_trace(go.Scatter(x=new_df[date_col], y=new_df[col], name=col), secondary_y=True)
+        else:
+            fig.add_trace(go.Scatter(x=new_df[date_col], y=new_df[col], name=col))
+    
+    fig.show()
\ No newline at end of file
